@@ -1035,7 +1035,7 @@ def download(
     else:
         encrypt_password = encrypt_password or _encrypt_password(ctx)
 
-    if not quiet:
+    if not quiet and downloader == "me":
         init_progress_bar()
 
     _download(
